Learn R Programming

SharpeR (version 1.0.0)

power.sropt_test: Power calculations for optimal Sharpe ratio tests

Description

Compute power of test, or determine parameters to obtain target power.

Usage

power.sropt_test(df1=NULL,df2=NULL,zeta.s=NULL,
                 sig.level=0.05,power=NULL,ope=1)

Arguments

df1
the number of assets in the portfolio.
df2
the number of observations.
zeta.s
the 'signal-to-noise' parameter, defined as ...
sig.level
Significance level (Type I error probability).
power
Power of test (1 minus Type II error probability).
ope
the number of observations per 'epoch'. For convenience of interpretation, The Sharpe ratio is typically quoted in 'annualized' units for some epoch, that is, 'per square root epoch', though returns are observed at a frequency of ope per epoc

Value

  • Object of class power.htest, a list of the arguments (including the computed one) augmented with method, note and n.epoch elements, the latter is the number of epochs under the given annualization (ope), NA if none given.

Details

Suppose you perform a single-sample test for significance of the optimal Sharpe ratio based on the corresponding single-sample T^2-test. Given any four of: the effect size (the population optimal SNR, $\zeta_*$), the number of assets, the number of observations, and the type I and type II rates, this function computes the fifth.

Exactly one of the parameters df1, df2, zeta.s, power, and sig.level must be passed as NULL, and that parameter is determined from the others. Notice that sig.level has non-NULL default, so NULL must be explicitly passed if you want to compute it.

See Also

reannualize

power.t.test, sropt_test

Other sropt: as.sropt, as.sropt.default, as.sropt.xts; confint.del_sropt, confint.sr, confint.sropt; dsropt, psropt, qsropt, rsropt; is.sropt; pco_sropt, qco_sropt; reannualize, reannualize.sr, reannualize.sropt; sropt_test; sropt

Examples

Run this code
anex <- power.sropt_test(8,4*253,1,0.05,NULL,ope=253)

Run the code above in your browser using DataLab