power.sropt_test(df1=NULL,df2=NULL,zeta.s=NULL,
sig.level=0.05,power=NULL,ope=1)ope per epocpower.htest, a list of the arguments
(including the computed one) augmented with method, note
and n.epoch elements, the latter is the number of epochs
under the given annualization (ope), NA if none given.Exactly one of the parameters df1, df2,
zeta.s, power, and
sig.level must be passed as NULL, and that parameter is determined
from the others. Notice that sig.level has non-NULL default, so NULL
must be explicitly passed if you want to compute it.
reannualizeOther sropt: as.sropt,
as.sropt.default,
as.sropt.xts;
confint.del_sropt,
confint.sr, confint.sropt;
dsropt, psropt,
qsropt, rsropt;
is.sropt; pco_sropt,
qco_sropt; reannualize,
reannualize.sr,
reannualize.sropt;
sropt_test; sropt
anex <- power.sropt_test(8,4*253,1,0.05,NULL,ope=253)Run the code above in your browser using DataLab